import { useState, useEffect } from 'react'
import type { SavedChecklist } from '../types'

const STORAGE_KEY = 'gocheck-saved-checklists'

export function useLocalStorage() {
  const [savedChecklists, setSavedChecklists] = useState<SavedChecklist[]>([])

  useEffect(() => {
    loadSavedChecklists()
  }, [])

  const loadSavedChecklists = () => {
    try {
      const saved = localStorage.getItem(STORAGE_KEY)
      if (saved) {
        setSavedChecklists(JSON.parse(saved))
      }
    } catch (error) {
      console.error('Error loading saved checklists:', error)
    }
  }

  const saveChecklist = (checklist: SavedChecklist) => {
    try {
      const updated = [checklist, ...savedChecklists.filter(c => c.uuid !== checklist.uuid)]
      localStorage.setItem(STORAGE_KEY, JSON.stringify(updated))
      setSavedChecklists(updated)
    } catch (error) {
      console.error('Error saving checklist:', error)
    }
  }

  const deleteChecklist = (uuid: string) => {
    try {
      const updated = savedChecklists.filter(c => c.uuid !== uuid)
      localStorage.setItem(STORAGE_KEY, JSON.stringify(updated))
      setSavedChecklists(updated)
    } catch (error) {
      console.error('Error deleting checklist:', error)
    }
  }

  const updateChecklistName = (uuid: string, newName: string) => {
    try {
      const updated = savedChecklists.map(c => 
        c.uuid === uuid ? { ...c, name: newName } : c
      )
      localStorage.setItem(STORAGE_KEY, JSON.stringify(updated))
      setSavedChecklists(updated)
    } catch (error) {
      console.error('Error updating checklist name:', error)
    }
  }

  const getChecklistName = (uuid: string): string | null => {
    const checklist = savedChecklists.find(c => c.uuid === uuid)
    return checklist ? checklist.name : null
  }

  return {
    savedChecklists,
    saveChecklist,
    deleteChecklist,
    updateChecklistName,
    getChecklistName,
    loadSavedChecklists
  }
} 